<?php

/**
  * This plugin lets you add addressbook entries from the compose window using the mouse
  * 
  * @author Cor Bosman (roundcube@wa.ter.net)
  */
  
class compose_addressbook extends rcube_plugin
{
  
  public function init()
  {  
    $this->register_action('plugin.get_addressbook', array($this, 'get_address'));
    $this->add_hook('render_page', array($this, 'add_button'));
  }
  
  // add a button to the compose template. The actual button is added in the javascript
  // after the next stable release this needs to be changed to use the newly added toolbar container in the compose template.
  public function add_button($p)
  {
    // find the compose template
    if($p['template'] == 'compose') {
      $this->add_texts('localization', true);
      $rcmail = rcmail::get_instance();
      
      // add javascript and stylesheets
      $this->include_script('compose_addressbook.js');
      
      // modal window jquery plugin
      $this->include_script('jqmodal/jqModal.js');
      
      // drag jquery plugin
      $this->include_script('jqmodal/jqDnR.js');
      
      // used by drag plugin to fix Safari and IE problems
      $this->include_script('jqmodal/dimensions.js');
      
      $this->include_stylesheet('jqmodal/jqModal.css');
      
      // create the (hidden) modal window
      $table_header = new html_table((array('class' => 'records-table', 'cols' => 2, 'cellspacing' => 0)));
      $table_header->add_header('compose_addressbook_name jqdrag', Q($this->gettext('compose_addressbook_title')));
      $table_header->add_header('compose_addressbook_name jqdrag compose_addressbook_close', html::a(array('href' => '#', 'class' => 'jqmClose'), 
                                                                           html::img(array('src'=>'plugins/compose_addressbook/images/close.png','title'=>Q($this->gettext('compose_addressbook_close'))))));
                                                                       
      $table = new html_table(array('id' => 'compose_addressbook_table', 'class' => 'records-table', 'cols' => 1, 'cellspacing' => 0));
       
      $rcmail->output->add_footer(html::div(array('id' => "compose_addressbook_modal"),
                                    $table_header->show() .
                                    html::div(array('id' => "compose_addressbook_container"),
                                      $table->show() . 
                                      html::div(array('id' => "compose_addressbook_quicksearchbar"),
                                        html::img(array('id'=>'compose_addressbook_searchmod','src'=>'/images/icons/glass.png')).
                                        html::tag('input', array('type' => "text", 'class' => 'compose_addressbook_filter','id'=>'compose_addressbook_filter')). 
                                        html::a(array('id' => 'compose_addressbook_searchreset', 'href'=>'#'),
                                          html::img(array('src'=>'/images/icons/reset.gif')))).
                                      html::p(array('class' => "compose_addressbook_formbuttons"),
                                        html::tag('input', array('type' => "submit", 'id' => 'rcmbtn_compose_addressbook_to', 'class' => "button", 'value' => $this->gettext('to'))) .
                                        html::tag('input', array('type' => "submit", 'id' => 'rcmbtn_compose_addressbook_cc', 'class' => "button", 'value' => $this->gettext('cc'))) .
                                        html::tag('input', array('type' => "submit", 'id' => 'rcmbtn_compose_addressbook_bcc', 'class' => "button", 'value' => $this->gettext('bcc')))
                                      )
                                    )
                                ));
                
      $this->load_config();    
      $rcmail->output->set_env('compose_addressbook_mode', $rcmail->config->get('compose_addressbook_mode', 'full'));
      $rcmail->output->add_gui_object('compose_addressbook_list', 'compose_addressbook_table');
      $rcmail->output->include_script('list.js');
                               
    }
  
    return($p);
  }
  
  // get the addressbook entries and return them to the UI.
  function get_address() {
    $contacts = array();
    $this->load_config('config.inc.php.dist');
    $this->load_config();
    $rcmail = rcmail::get_instance();
    
    $mode = $rcmail->config->get('compose_addressbook_mode', 'full');
        
    // get the addressbooks, or default to autocomplete_addressbooks
    $book_types = (array) $rcmail->config->get('compose_addressbooks', $rcmail->config->get('autocomplete_addressbooks', 'sql'));
    
    foreach ($book_types as $id) {
      $abook = $rcmail->get_address_book($id);
      $abook->set_pagesize(50000);
    
      if($mode == 'full') {
        $result = $abook->list_records();
        while ($sql_arr = $result->iterate()) {
          if($sql_arr['name'] == '') $sql_arr['name'] = $sql_arr['email'];
          $contacts[] = array('name' => $sql_arr['name'] , 'email' => format_email_recipient($sql_arr['email'], $sql_arr['name']));
        }
      } else {
        $search=trim(get_input_value('_search', RCUBE_INPUT_POST));
        
        if(!empty($search)) {
          $result = $abook->search(array('name','email'),$search);
          while ($arr = $result->iterate()) {
            if($arr['name'] == '') $arr['name'] = $arr['email'];
            $res = array('name' => $arr['name'] , 'email' => format_email_recipient($arr['email'], $arr['name']));
            if(!in_array($res,$contacts))
              $contacts[] = $res;
          }
      }
      }
    }
    sort($contacts);
    
    // send the addressbook back to javascript
    $rcmail->output->command('plugin.compose_addressbook_receive', array('addresses' => $contacts));    
  }
  
}
?>
